@@ -2,9 +2,10 @@ package AnyEvent::Filesys::Notify;
 
 # ABSTRACT: An AnyEvent compatible module to monitor files/directories for changes
 
-use Moose;
-use Moose::Util qw(apply_all_roles);
-use namespace::autoclean;
+use Moo;
+use Moo::Role ();
+use MooX::late;
+use namespace::sweep;
 use AnyEvent;
 use Path::Iterator::Rule;
 use Cwd qw/abs_path/;
@@ -12,7 +13,7 @@ use AnyEvent::Filesys::Notify::Event;
 use Carp;
 use Try::Tiny;
 
-our $VERSION = '0.22';
+our $VERSION = '0.24';
 my $AEFN = 'AnyEvent::Filesys::Notify';
 
 has dirs        => ( is => 'ro', isa => 'ArrayRef[Str]', required => 1 );
@@ -168,44 +169,42 @@ sub _load_backend {
         my $backend = $self->backend;
         $backend = $prefix . $backend unless $backend =~ s{^\+}{};
 
-        try { apply_all_roles( $self, $backend ); }
+        try { Moo::Role->apply_roles_to_object( $self, $backend ); }
         catch {
             croak "Unable to load the specified backend ($backend). You may "
               . "need to install Linux::INotify2, Mac::FSEvents or IO::KQueue:"
               . "\n$_";
         }
     } elsif ( $self->no_external ) {
-        apply_all_roles( $self, "${AEFN}::Role::Fallback" );
+        Moo::Role->apply_roles_to_object( $self, "${AEFN}::Role::Fallback" );
     } elsif ( $^O eq 'linux' ) {
-        try { apply_all_roles( $self, "${AEFN}::Role::Inotify2" ); }
+        try { Moo::Role->apply_roles_to_object( $self, "${AEFN}::Role::Inotify2"); }
         catch {
             croak "Unable to load the Linux plugin. You may want to install "
               . "Linux::INotify2 or specify 'no_external' (but that is very "
               . "inefficient):\n$_";
         }
     } elsif ( $^O eq 'darwin' ) {
-        try { apply_all_roles( $self, "${AEFN}::Role::FSEvents" ); }
+        try { Moo::Role->apply_roles_to_object( $self, "${AEFN}::Role::FSEvents" ); }
         catch {
             croak "Unable to load the Mac plugin. You may want to install "
               . "Mac::FSEvents or specify 'no_external' (but that is very "
               . "inefficient):\n$_";
         }
     } elsif ( $^O eq 'freebsd' ) {
-        try { apply_all_roles( $self, "${AEFN}::Role::KQueue" ); }
+        try { Moo::Role->apply_roles_to_object( $self, "${AEFN}::Role::KQueue" ); }
         catch {
             croak "Unable to load the FreeBSD plugin. You may want to install "
               . "IO::KQueue or specify 'no_external' (but that is very "
               . "inefficient):\n$_";
         }
     } else {
-        apply_all_roles( $self, "${AEFN}::Role::Fallback" );
+        Moo::Role->apply_roles_to_object( $self, "${AEFN}::Role::Fallback" );
     }
 
     return 1;
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
@@ -218,7 +217,7 @@ AnyEvent::Filesys::Notify - An AnyEvent compatible module to monitor files/direc
 
 =head1 VERSION
 
-version 0.22
+version 0.24
 
 =head1 SYNOPSIS
 
